@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import os
 import sys
 import unittest
@@ -18,9 +17,12 @@ class TestExampleController(unittest.TestCase):
 
     @property
     def mongo_db(self):
-        from pyramid_rest.mongo import IMongoConnection
+        from pyramid_mongokit import IMongoConnection
         return getattr(
-            self.app.app.registry.getUtility(IMongoConnection),
+            self.app.app.registry.getUtility(
+                IMongoConnection,
+                'mongo_connection',
+                ),
             os.environ['MONGO_DB_NAME']
             )
 
