@@ -30,9 +30,3 @@ class TestBson(unittest.TestCase):
         result = bson_loads(bson_dumps(o))
 
         self.assertEqual(o, result)
-
-
-class TestRestFactory(unittest.TestCase):
-
-    def test_call(self):
-        from pyramid_rest.renderer import Factory
